@@ -8,10 +8,10 @@ package Devel::MAT;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use Carp;
-use List::Util qw( pairs );
+use List::Util qw( first pairs );
 use List::UtilsBy qw( sort_by );
 
 use Devel::MAT::Dumpfile;
@@ -143,6 +143,21 @@ sub load_tool
    return $self->{tools}{$name} ||= $tool_class->new( $self, %args );
 }
 
+sub load_tool_for_command
+{
+   my $self = shift;
+   my ( $cmd, %args ) = @_;
+
+   return $self->{tools_by_command}{$cmd} ||= do {
+      my $name = first {
+         my $class = "Devel::MAT::Tool::$_";
+         $class->can( "CMD" ) and $class->CMD eq $cmd
+      } $self->available_tools or die "Unrecognised command '$cmd'";
+
+      $self->load_tool( $name );
+   };
+}
+
 =head2 inref_graph
 
    $node = $pmat->inref_graph( $sv, %opts )
