@@ -8,7 +8,7 @@ package Devel::MAT::Dumper;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use File::Basename qw( basename );
 
@@ -59,14 +59,6 @@ the interpreter exits.
 
    $ perl -MDevel::MAT::Dumper=-dump_at_END ...
 
-=head2 -dump_at_SIGABRT
-
-Installs a handler for C<SIGABRT> to write a dump file if the signal is
-received. After dumping the file, the signal handler is removed and the signal
-re-raised.
-
-   $ perl -MDevel::MAT::Dumper=-dump_at_SIGABRT ...
-
 =head2 -dump_at_SIGQUIT
 
 Installs a handler for C<SIGQUIT> to write a dump file if the signal is
@@ -75,6 +67,14 @@ times.
 
    $ perl -MDevel::MAT::Dumper=-dump_at_SIGQUIT ...
 
+=head2 -dump_at_SIGI<NAME>
+
+Installs a handler for the named signal (e.g. C<SIGABRT>, C<SIGINT>) to write
+a dump file if the signal is received. After dumping the file, the signal
+handler is removed and the signal re-raised.
+
+   $ perl -MDevel::MAT::Dumper=-dump_at_SIGABRT ...
+
 =head2 -file $PATH
 
 Sets the name of the file which is automatically dumped; defaults to basename
@@ -145,15 +145,6 @@ sub import
       elsif( $sym eq "-dump_at_END" ) {
          $dump_at_END++;
       }
-      elsif( $sym eq "-dump_at_SIGABRT" ) {
-         $SIG{ABRT} = sub {
-            ( my $file = $dumpfile_name ) =~ s/NNN/$next_serial++/e;
-            print STDERR "Dumping to $file because of SIGABRT\n";
-            Devel::MAT::Dumper::dump( $file );
-            undef $SIG{ABRT};
-            kill ABRT => $$;
-         };
-      }
       elsif( $sym eq "-dump_at_SIGQUIT" ) {
          $SIG{QUIT} = sub {
             ( my $file = $dumpfile_name ) =~ s/NNN/$next_serial++/e;
@@ -161,6 +152,18 @@ sub import
             Devel::MAT::Dumper::dump( $file );
          };
       }
+      elsif( $sym =~ m/^-dump_at_SIG(\S+)$/ ) {
+         my $signal = $1;
+         exists $SIG{$signal} or die "Unrecognised signal name SIG$signal\n";
+
+         $SIG{$signal} = sub {
+            ( my $file = $dumpfile_name ) =~ s/NNN/$next_serial++/e;
+            print STDERR "Dumping to $file because of SIG$signal\n";
+            Devel::MAT::Dumper::dump( $file );
+            undef $SIG{$signal};
+            kill $signal => $$;
+         };
+      }
       elsif( $sym eq "-file" ) {
          $dumpfile_name = shift;
       }
