@@ -10,7 +10,7 @@ use warnings;
 use feature qw( switch );
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -66,7 +66,7 @@ sub register_type
    # generate the ->type constant method
    ( my $typename = $_[0] ) =~ s/^Devel::MAT::SV:://;
    no strict 'refs';
-   *{"$_[0]::type"} = sub () { $typename };
+   *{"$_[0]::type"} = sub () { $typename } unless defined *{"$_[0]::type"}{CODE};
 }
 
 sub new
@@ -364,7 +364,7 @@ boolean true and false. They are
 
 package Devel::MAT::SV::Immortal;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 use constant immortal => 1;
 sub new {
    my $class = shift;
@@ -377,13 +377,13 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::UNDEF;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
 package Devel::MAT::SV::YES;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 sub desc { "YES" }
 sub type { "SCALAR" }
 
@@ -398,7 +398,7 @@ sub name {}
 
 package Devel::MAT::SV::NO;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 sub desc { "NO" }
 sub type { "SCALAR" }
 
@@ -413,7 +413,7 @@ sub name {}
 
 package Devel::MAT::SV::Unknown;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 0xff );
 
 sub desc { "UNKNOWN" }
@@ -422,7 +422,7 @@ sub _outrefs {}
 
 package Devel::MAT::SV::GLOB;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 1 );
 
 =head1 Devel::MAT::SV::GLOB
@@ -575,7 +575,7 @@ sub _outrefs
 
 package Devel::MAT::SV::SCALAR;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 2 );
 
 =head1 Devel::MAT::SV::SCALAR
@@ -697,6 +697,13 @@ sub name
    return '$' . $self->df->sv_at( $glob_at )->stashname;
 }
 
+sub type
+{
+   my $self = shift;
+   return "SCALAR" if defined $self->uv or defined $self->iv or defined $self->nv or defined $self->pv;
+   return "UNDEF";
+}
+
 sub desc
 {
    my $self = shift;
@@ -707,6 +714,7 @@ sub desc
    push @flags, "NV" if defined $self->nv;
    push @flags, "PV" if defined $self->pv;
    local $" = ",";
+   return "UNDEF()" unless @flags;
    return "SCALAR(@flags)";
 }
 
@@ -721,7 +729,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REF;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 3 );
 
 =head1 Devel::MAT::SV::REF
@@ -798,7 +806,7 @@ sub _outrefs
 
 package Devel::MAT::SV::ARRAY;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 4 );
 
 =head1 Devel::MAT::SV::ARRAY
@@ -918,7 +926,7 @@ sub _outrefs
 package Devel::MAT::SV::PADLIST;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 use constant type => "PADLIST";
 
 =head1 Devel::MAT::SV::PADLIST
@@ -954,7 +962,7 @@ sub _outrefs
 package Devel::MAT::SV::PADNAMES;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 use constant type => "PADNAMES";
 
 =head1 Devel::MAT::SV::PADNAMES
@@ -1030,7 +1038,7 @@ sub _outrefs
 package Devel::MAT::SV::PAD;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 use constant type => "PAD";
 
 use List::Util qw( pairmap );
@@ -1091,7 +1099,7 @@ sub _outrefs
 
 package Devel::MAT::SV::HASH;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 5 );
 
 =head1 Devel::MAT::SV::HASH
@@ -1221,7 +1229,7 @@ sub _outrefs
 
 package Devel::MAT::SV::STASH;
 use base qw( Devel::MAT::SV::HASH );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 6 );
 
 =head1 Devel::MAT::SV::STASH
@@ -1341,12 +1349,12 @@ sub _outrefs
 
 package Devel::MAT::SV::CODE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 7 );
 
 use Carp;
 
-use List::MoreUtils qw( uniq );
+use List::Util 1.44 qw( uniq );
 
 use Struct::Dumb 0.07 qw( readonly_struct );
 readonly_struct Padname => [qw( name ourstash )];
@@ -1785,7 +1793,7 @@ sub _outrefs
 
 package Devel::MAT::SV::IO;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 8 );
 
 sub load
@@ -1815,7 +1823,7 @@ sub _outrefs
 
 package Devel::MAT::SV::LVALUE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 9 );
 
 sub load
@@ -1848,7 +1856,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REGEXP;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 10 );
 
 sub load {}
@@ -1859,7 +1867,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::FORMAT;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 11 );
 
 sub load {}
@@ -1870,7 +1878,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::INVLIST;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 __PACKAGE__->register_type( 12 );
 
 sub load {}
