@@ -8,7 +8,9 @@ package Devel::MAT::Tool::Count;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
+
+use constant CMD => "count";
 
 =head1 NAME
 
@@ -20,8 +22,11 @@ This C<Devel::MAT> tool counts the different kinds of SV in the heap.
 
 =cut
 
-# No instance
-sub new { shift }
+sub new
+{
+   my $class = shift;
+   return bless { df => shift->dumpfile }, $class;
+}
 
 =head1 METHODS
 
@@ -61,6 +66,19 @@ sub count_svs
    return \%kinds, \%blessed_kinds;
 }
 
+sub run_cmd
+{
+   my $self = shift;
+
+   Devel::MAT::Cmd->printf( "  %-20s %-10s %-10s\n", "Kind", "Count", "(blessed)" );
+
+   my ( $kinds, $blessed ) = $self->count_svs( $self->{df} );
+
+   foreach my $kind ( sort keys %$kinds ) {
+      Devel::MAT::Cmd->printf( "  %-20s %-10s %-10s\n", $kind, $kinds->{$kind}, $blessed->{$kind} // "" );
+   }
+}
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
