@@ -10,7 +10,7 @@ use warnings;
 use feature qw( switch );
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use constant FOR_UI => 1;
 
@@ -267,7 +267,7 @@ sub mark_reachable
 
                push @more_internal, $lv->target if $lv->target;
             }
-            when([ "SCALAR", "IO", "REGEXP", "FORMAT" ]) { } # ignore
+            when([ "UNDEF", "SCALAR", "IO", "REGEXP", "FORMAT" ]) { } # ignore
 
             default { warn "Not sure what to do with user data item ".$sv->desc_addr."\n"; }
          }
